#
# spec file for package python-mutagen
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-mutagen
Version:        1.43.0
Release:        lp152.2.1
Summary:        Python module to Handle Audio Metadata
License:        GPL-2.0-or-later
Group:          Development/Libraries/Python
URL:            https://pypi.python.org/pypi/mutagen
Source:         https://files.pythonhosted.org/packages/source/m/mutagen/mutagen-%{version}.tar.gz
# PATCH-FIX-OPENSUSE reduce-test-length.diff alarrosa@suse.com -- Reduce the number of iterations so tests don't take so long to finish
Patch0:         reduce-test-length.diff
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Requires:       python-setuptools
%python_subpackages

%description
Mutagen is a Python module to handle audio metadata. It supports FLAC,
M4A, MP3, Ogg FLAC, Ogg Speex, Ogg Theora, Ogg Vorbis, True Audio, and
WavPack audio files. All versions of ID3v2 are supported, and all
standard ID3v2.4 frames are parsed. It can read Xing headers to
accurately calculate the bitrate and length of MP3s. ID3 and APEv2 tags
can be edited regardless of their audio format. It can also manipulate
Ogg streams on an individual packet/page level.

%prep
%setup -q -n mutagen-%{version}
%patch0 -p1
# remove shebangs from library files
find mutagen/ -name "*.py" -exec sed -i -e '/^#!\s\?\/usr\/bin\/\(env\s\)\?python$/d' {} ';'

%build
%python_build

%install
%python_install

for i in mid3cp mid3iconv mid3v2 moggsplit mutagen-inspect mutagen-pony; do
   %python_clone -a %{buildroot}%{_bindir}/${i}
   %python_clone -a %{buildroot}%{_mandir}/man1/${i}.1
done
%python_expand %fdupes %{buildroot}%{$python_sitelib}/mutagen

%post
%{python_install_alternative mid3cp mid3iconv mid3v2 moggsplit mutagen-inspect mutagen-pony mid3cp.1 mid3iconv.1 mid3v2.1 moggsplit.1 mutagen-inspect.1 mutagen-pony.1}

%preun
%{python_uninstall_alternative mid3cp}

%check
export LANG=en_US.UTF-8
#export PATH="$PATH:%%{buildroot}%%{_bindir}"
%python_exec setup.py test --no-quality

%files %{python_files}
%defattr(-, root, root, 0755)
%license COPYING
%doc NEWS README.rst
%python_alternative %{_bindir}/mid3cp
%python_alternative %{_bindir}/mid3iconv
%python_alternative %{_bindir}/mid3v2
%python_alternative %{_bindir}/moggsplit
%python_alternative %{_bindir}/mutagen-inspect
%python_alternative %{_bindir}/mutagen-pony
%python_alternative %{_mandir}/man1/mid3cp.1%{ext_man}
%python_alternative %{_mandir}/man1/mid3iconv.1%{ext_man}
%python_alternative %{_mandir}/man1/mid3v2.1%{ext_man}
%python_alternative %{_mandir}/man1/moggsplit.1%{ext_man}
%python_alternative %{_mandir}/man1/mutagen-inspect.1%{ext_man}
%python_alternative %{_mandir}/man1/mutagen-pony.1%{ext_man}
%{python_sitelib}/mutagen
%{python_sitelib}/mutagen-%{version}-py%{python_version}.egg-info

%changelog
* Fri Jan 10 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.43.0:
  * Python 3.4 is no longer supported
  * Building requires ‘setuptools’ now, CLI tools depend on
    ‘pkg_resources’
  * CLI tools are setuptools entry points now
  * Fix collections ABCs deprecation warning #pr371
  * Minor typo fixes #pr375
  * MP3: increase max initial wrong syncs from 1000 to 1500 #pr376
  * FLAC: support files with multiple VORBIS_COMMENT blocks like
    libflac #pr378
  * ID3: Improved TYER/TDAT/TIME upgrade to TDRC #pr385
  * MP4: Add support for iTunes HD Video tag (hdvd) #pr386
  * Add AC3 file type #pr400
  * AIFF: renamed sample_size to bits_per_sample (sample_size still
    works) #pr403
  * API doc fixes #pr404 #pr407
  * Add support for Tom’s lossless Audio Kompressor (TAK) #pr405
  * OptimFROG: support encoder version >= 5.100 #pr406
  * AIFF: Fix handling of padding bytes, safe chunk manipulation #pr409
  * Fix typos #pr412
- Add Requires: python-setuptools since CLI tools now depend on it
* Fri Mar  1 2019 John Vandenberg <jayvdb@gmail.com>
- Remove unnecessary build dependencies on code style linters,
  by using upstream provided `setup.py test --no-quality`,
  discarding 0001-pycodestyle-fix-new-warnings.patch
* Tue Feb  5 2019 Antonio Larrosa <alarrosa@suse.com>
- Add 0001-pycodestyle-fix-new-warnings.patch from upstream to fix a
  pep8 error in the tests that makes the package fail to build.
* Fri Dec 28 2018 sean@suspend.net
- update to version 1.42.0:
  * id3: always read id3v1 tags and include them when no id3v2 exists
  * id3: add a pretty print implementation for SYLT
  * vorbis: improved error messages when validating keys/values
  * Fix pylint warnings when using various save() methods
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Aug  5 2018 adrian@suse.de
- update to version 1.41.0:
  * Documentation fixes :pr:`342` (:user:`Jakub Wilk <jwilk>`)
  * mid3v2: Add support for WXXX frames :bug:`344` :bug:`348`
  * Fix decoding of track_peak from MP3 Info Tag :pr:`345`
    (:user:`Anton Yuzhaninov <citrin>`)
  * MonkeysAudio: set bits_per_sample for older files :bug:`347`
- drop obsolete ignore-W504.patch
* Thu Apr 12 2018 alarrosa@suse.com
- Update to version 1.40.0:
  * APEv2: Ensures tags are saved in a deterministic way
  * easymp4: Fix EasyMP4.add_tags() when no tags exist
  * id3: Fix PyCharm not being able to resolve id3 frame class references
  * Support pathlib.Path objects for paths (PEP 519)
  * Use semver for versioning
- Add ignore-W504.patch to ignore PEP8's W504 messages which make the pep8
  test fail.
* Fri Nov 10 2017 alarrosa@suse.com
- Update to version 1.39:
  * Tests:
  * Require hypothesis
  * Run pycodestyle/pyflakes tests by default. Skip with --no-quality or
  - m no quality when using pytest directly.
  * Python 3.3 is no longer supported
  * MP3: Improved bitrate accuracy for files with XING header
  * ASF: Fix case where some tags resulted in broken ASFUnicodeAttribute
    instances
  * Add support for filesystems which don’t support opening files read/write
    (gvfs over fuse for example)
  * mid3v2: Add support for USLT
  * Other minor improvements
- Update to version 1.38:
  * ID3:
  * Add iTunes grouping frame id3.GRP1
  * Fix exposing text frames where the text can’t be encoded with
    the reported encoding due to merging of frames
  * OGG: Fix wrong StreamInfo.length (small negative value) for all
    ogg based formats in rare cases.
- Rebased the reduce-test-length.diff patch.
- Added the hypothesis, pycodestyle and pyflakes python modules to the
  BuildRequires, since they are needed for the tests.
* Thu Apr  6 2017 alarrosa@suse.com
- Use singlespec macros.
- Drop fix-tests-tools-names.diff which is not needed anymore.
- Add reduce-test-length.diff to reduce the number of iterations in a test
  that is repeated for each data test file, for every byte, so it only tests
  each file for the first 10 bytes. This way we reduce the time it takes to
  test mutagen (and the corresponding cpu usage in obs) from 1078 seconds
  (nearly 18 minutes) to 53 seconds (for each python version).
* Wed Mar 22 2017 tbechtold@suse.com
- Use files.pythonhosted.org for Source url
* Thu Mar 16 2017 alarrosa@suse.com
- update to version 1.37:
  * Relicense "GPLv2" → "GPLv2 or later" :bug:`291`
  * DSF: add `mutagen.dsf` module for DSF (DSD Stream File) support
    :pr:`283` (Boris Pruessmann)
  * MP3: Add `mp3.MPEGInfo.encoder_settings` containing a guess of the encoder
    settings used, for example ``"-V2"`` for LAME :bug:`66`
  * ID3: add iTunes movement related frames `id3.MVIN` and `id3.MVNM`
  * MP4: support ``©mvi``, ``©mvc``, ``shwm``, ``stik``, ``rtng``, ``tves``,
    ``tvsn``, ``plID``, ``cnID``, ``geID``, ``atID``, ``sfID``, ``cmID``,
    ``akID`` :bug:`130`
- update to version 1.36.3:
  * MP3: fix error with xing frames without a frame count :bug:`292`
- Run spec file through spec-cleaner
* Wed Jan 25 2017 alarrosa@suse.com
- update to version 1.36.2:
  * ID3: Always write little endian utf-16 with BOM.
    Fixes tests on big endian machines :pr:`289`
- update to version 1.36.1:
  * Support GAE runtime :bug:`286`
  * FLAC: Fix crash when loading files with zero samples :bug:`287`
  * MP3: Handle broken lame tags written by older lame versions
- update to version 1.36:
  * ID3: Ignore trailing empty values for v2.3 text frames :bug:`276`
  * ID3: Write large APIC frames last :bug:`278`
  * EasyID3: support saving as v2.3 :bug:`188`
  * FLAC: Add StreamInfo.bitrate :bug:`279`
  * mid3cp: Add ``--merge`` option :bug:`277`
  * MP4: Allow loading files without audio tracks :bug:`272`
- update to version 1.35.1:
  * Revert back to distutils :bug:`273`
- update to version 1.35:
  * Tests: Require pytest
  * Tools: Install .exe launchers on Windows
  * setup.py: Require setuptools
  * ID3:
  * Fix loading files with CRM frames :bug:`239`
  * Fix loading AENC, LINK, GRID frames with no payload
  * Merge duplicate text frames with same key on load :bug:`172`
  * Allow parsing of duplicate APIC frames :bug:`172`
  * Parse utf-16 text fields with missing BOM :bug:`267`
  * Increase max resyncs for the mpeg frame search :bug:`268`
- Add fix-tests-tools-names.diff. This fixes the tests to run
  successfully since they try to extract the module name from the tool
  name, but we changed the tools names so they can be co-installed
  with the python2 version of the tools, so we have to remove the
  "-3" suffix before importing the modules.
- Fix update-alternatives execution as mutagen-inspect and mutagen-pony
  binaries had manpage suffixes so alternative links were not created.
- Drop fix_SynchronizedTextSpec_test_on_BE.patch (upstream included it).
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Mon Apr 11 2016 normand@linux.vnet.ibm.com
- fix_SynchronizedTextSpec_test_on_BE.patch for ppc64 archi
  as per upstream commit Id c4d43fa
* Thu Jan 14 2016 toddrme2178@gmail.com
- Update to 1.31
  * New padding control API for flac/id3/mp4/asf/ogg/aiff and everything
    based on it, except oggflac :bug:`229`
  * Mutagen will now reduce padding on save if there is lots of it.
  * delete() will remove padding in addition to tags.
  * ASF:
  * Padding support :bug:`201`
  * Don't report negative lengths for some broken files
  * New :class:`asf.ASFInfo`.codec_type/codec_name/codec_description
  * Implement ASF.delete()
  * OGG: Padding support for Opus/Vorbis/Theora/Speex
  * M4A: Implementation removed. Every operation will raise. Use mp4 instead.
  * Tools: Support Unicode output under Windows :bug:`232`
- Update to 1.30
  * FLAC:
  * Fix :meth:`flac.FLAC.save` in case the source contained a too large
    (invalid but recovered) image block :bug:`226`
  * MP3:
  * Improved length and bitrate accuracy:
  * Read lame "Info" tags for improved bitrate/length accuracy
  * Use bytes info of VBRI headers for improved bitrate accuracy
  * Subtract encoder delay/padding from length for improved length accuracy
    (especially for short tracks)
  * Fix rare false identification of Xing headers :bug:`182`
  * New :class:`mp3.MPEGInfo`.encoder_info attribute containing the encoder
    name and version :bug:`66`
  * New :class:`mp3.MPEGInfo`.bitrate_mode attribute exposing if the file is
    VBR, ABR or CBR :bug:`24` :bug:`66`
  * New :class:`mp3.MPEGInfo`.channels attribute providing the channel count
  * New :class:`mp3.MPEGInfo`.track_gain/track_peak/album_gain values exposing
    the replaygain info provided by the lame header :bug:`36`
  * ID3:
  * New :class:`id3.PictureType` enum for the picture type used in APIC frames :bug:`222`
  * MP4:
  * Fix MP4FreeForm.__eq__ and MP4Cover.__eq__ when comparing with bytes
    :bug:`218`
  * Don't raise on :meth:`FileType.save` if there are no tags. :bug:`227`
  * Minor fixes: :bug:`228`
- Update to 1.29
  * mid3v2: Fix an error under Python 3 with files without tags :bug:`219`
  * mid3v2: Various Windows+Python2+Unicode fixes :bug:`214`
  * Don't emit warnings during loading (ID3Warning) :bug:`223`
  * py.test support
- Clean up update-alternatives
- Implement unit tests
* Thu Apr  2 2015 aplanas@suse.com
- Updated to 1.28
  * Various minor fixes to make mutagen behave the same under Python3 as under Python2.
  * Update gpl text [205]
  * Documentation: Add example for how to create a new flac.Picture [209]
  * ID3:
  * Various error handling fixes ([110], [211], ...)
  * Don’t hide ID3 loading errors with ID3FileType.
  * In case a synch safe marked frame isn’t sync safe, only warn [210]
  * Removed PEDANTIC mode
  * Tools:
  * Add signal handling [170]
  * mid3cp: Make it work under Windows.
  * mutagen-inspect: Make it work under Windows+Python3 [216]
  * Support unicode file paths under Windows+Python2 [214]
  * Support file paths with invalid encoding under Unix+Python3.
- Adapt the spec file for SLE11
- Replace names of scripts in setup.py
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Mon Oct 14 2013 i@marguerite.su
- Implement update-alternatives
  * prepare for python3-mutagenx, which has the same binaries/manpages
    as this one but still in python2 state.
  * it just doesn't hurt...
* Sun Oct 13 2013 p.drouand@gmail.com
- Replace python-distribute with python-setuptools BuildRequires
- Remove Requires: python = %%{py_ver}; it's useless
* Sat Oct 12 2013 i@marguerite.su
- update to 1.22:
  * Minimum required Python version is now 2.6
  * Online API reference at https://mutagen.readthedocs.org/
  * EasyID3:
  * Fix crash with empty TXXX values. (#135)
  * ID3:
  * id3v2.3 writing support (#85)
  * Add iTunes podcast frames (TGID, TDES, WFED) (#141)
  * Updated id3v1 genre list
  * MP4:
  * add_tags() will not replace existing tags. (#101)
  * Don't ignore tags if parsing unknown atoms fails.
  * Raise on invalid 64bit atom size (#132, Sidnei da Silva)
  * APEv2:
  * Handle invalid tag item count. (#145, Dawid Zamirski)
  * Ogg:
  * Faster parsing of files with large packets.
  * VComment:
  * Preserve text case for field names added through the dict interface (#152)
  * mid3v2:
  * New -e,--escape switch to enable interpretation of escape sequences and
    makes escaping of the colon separator possible. (#159)
  * mid3iconv:
  * Convert COMM frames (#128)
- clean spec and don't use the INSTALLED_FILES way, which make this spec
  contains no useful information exposed on web
  * expand %%py_requires or SP1 won't build
  * add BuildRequires: python-distrubite because it used setup.py
  * remove the entire %%clean section, unneeded now
  * TUTORIAL is no more, so no need of dos2unix too.
* Tue Oct 26 2010 boris@steki.net
- spec file fixes
  * fixed suse version for OS11.2 as it have noarch detected correctly
  * remove shebangs from library files
  * simplified fix for compressed manual pages
* Tue Sep 14 2010 coolo@novell.com
- update to 1.20:
  * tons of changes in two years time, support for almost everything
    improved, see NEWS file for a lengthy description
* Tue Jun 24 2008 dmueller@suse.de
- update to 1.14:
  * MP4/M4A: Fixed saving of atoms with 64-bit size on 64-bit platforms.
  * MP4: Conversion of 'gnre' atoms to '\xa9gen' text atoms now correctly
    produces a list of string values, not just a single value.
  * ID3: Broken RVA2 frames are now discarded. (Vladislav Naumov)
  * ID3: Use long integers when appropriate.
  * VCommentDict: Raise UnicodeEncodeErrors when trying to use a Unicode
    key that is not valid ASCII; keys are also normalized to ASCII
    str objects. (Forest Bond)
* Wed Jan 16 2008 hvogel@suse.de
- Update to version 1.13
  * FLAC: Raise IOError, instead of UnboundLocalError, when trying
    to open a non-existant file. (Lukáš Lalinský, Debian #448734)
  * Throw out invalid frames when upgrading from 2.3 to 2.4.
  * Fixed reading of Unicode strings from ASF files on big-endian
  platforms.
  * TCP/TCMP support.
  * Faster implementation of file-writing when mmap fails, and
  exclusive advisory locking when available.
  * Use VBRI header to calculate length of VBR MP3 files if the Xing
  header is not found.
  * Write important ID3v2 frames near the start. (Lukáš Lalinský)
* Wed Jul  4 2007 hvogel@suse.de
- Initial package, Version 1.11
